import { DVCClient as Client, DVCFeatureSet, DVCOptions, DVCVariableSet, DVCVariableValue, DVCEvent as ClientEvent, DVCUser, ErrorCallback, DVCFeature, VariableDefinitions } from './types';
import { DVCVariable } from './Variable';
import { DVCPopulatedUser } from './User';
import { EventEmitter } from './EventEmitter';
import { BucketedUserConfig, VariableTypeAlias } from '@devcycle/types';
import { DVCLogger } from '@devcycle/types';
type variableUpdatedHandler = (key: string, variable: DVCVariable<DVCVariableValue> | null) => void;
type featureUpdatedHandler = (key: string, feature: DVCFeature | null) => void;
type newVariablesHandler = () => void;
type errorHandler = (error: unknown) => void;
type initializedHandler = (success: boolean) => void;
type configUpdatedHandler = (newVars: DVCVariableSet) => void;
type variableEvaluatedHandler = (key: string, variable: DVCVariable<DVCVariableValue>) => void;
export type DVCOptionsWithDeferredInitialization = DVCOptions & {
    deferInitialization: true;
};
export declare const isDeferredOptions: (arg: DVCUser | DVCOptionsWithDeferredInitialization) => arg is DVCOptionsWithDeferredInitialization;
export declare class DVCClient<Variables extends VariableDefinitions = VariableDefinitions> implements Client<Variables> {
    private readonly options;
    private onInitialized;
    private resolveOnInitialized;
    private variableDefaultMap;
    private sdkKey;
    private userSaved;
    private _closing;
    private isConfigCached;
    private initializeTriggered;
    logger: DVCLogger;
    config?: BucketedUserConfig;
    user?: DVCPopulatedUser;
    private store;
    private eventQueue;
    private requestConsolidator;
    eventEmitter: EventEmitter;
    private streamingConnection?;
    private pageVisibilityHandler?;
    private inactivityHandlerId?;
    private windowMessageHandler?;
    constructor(sdkKey: string, options: DVCOptionsWithDeferredInitialization);
    constructor(sdkKey: string, user: DVCUser, options?: DVCOptions);
    /**
     * Logic to initialize the client with the appropriate user and configuration data by making requests to DevCycle
     * and loading from local storage. This either happens immediately on client initialization, or when the user is
     * first identified (in deferred mode)
     * @param initialUser
     */
    private clientInitialization;
    onClientInitialized(): Promise<DVCClient<Variables>>;
    onClientInitialized(onInitialized: ErrorCallback<DVCClient<Variables>>): void;
    variable<K extends string & keyof Variables, T extends DVCVariableValue & Variables[K]>(key: K, defaultValue: T): DVCVariable<T>;
    variableValue<K extends string & keyof Variables, T extends DVCVariableValue & Variables[K]>(key: K, defaultValue: T): VariableTypeAlias<T>;
    identifyUser(user: DVCUser): Promise<DVCVariableSet>;
    identifyUser(user: DVCUser, callback?: ErrorCallback<DVCVariableSet>): void;
    private _identifyUser;
    resetUser(): Promise<DVCVariableSet>;
    resetUser(callback: ErrorCallback<DVCVariableSet>): void;
    allFeatures(): DVCFeatureSet;
    allVariables(): DVCVariableSet;
    subscribe(key: `variableUpdated:${string}`, handler: variableUpdatedHandler): void;
    subscribe(key: `newVariables:${string}`, handler: newVariablesHandler): void;
    subscribe(key: `featureUpdated:${string}`, handler: featureUpdatedHandler): void;
    subscribe(key: `variableEvaluated:${string}`, handler: variableEvaluatedHandler): void;
    subscribe(key: 'error', handler: errorHandler): void;
    subscribe(key: 'initialized', handler: initializedHandler): void;
    subscribe(key: 'configUpdated', handler: configUpdatedHandler): void;
    unsubscribe(key: string, handler?: (...args: any[]) => void): void;
    track(event: ClientEvent): void;
    flushEvents(callback?: () => void): Promise<void>;
    close(): Promise<void>;
    get closing(): boolean;
    private refetchConfig;
    private handleConfigReceived;
    private onSSEMessage;
    private registerVisibilityChangeHandler;
    private getConfigCache;
}
export {};
